@@ -1,6 +1,6 @@
 # library.py
 #
-# Copyright 2022 brombinmirko <send@mirko.pm>
+# Copyright 2025 mirkobrombin <brombin94@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
 from gettext import gettext as _
 
-from gi.repository import Gtk, Gdk
+from gi.repository import Gdk, Gtk
 
 from bottles.backend.logger import Logger
 from bottles.backend.managers.library import LibraryManager
