@@ -1,6 +1,6 @@
 # depscheck.py
 #
-# Copyright 2022 brombinmirko <send@mirko.pm>
+# Copyright 2025 mirkobrombin <brombin94@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from gi.repository import Gtk, Adw
+from gi.repository import Adw, Gtk
 
 
 @Gtk.Template(resource_path="/com/usebottles/bottles/dialog-deps-check.ui")
